@@ -1,7 +1,8 @@
+# Create small bitmap icon images.
+# Bitmap editor: http://www.posoft.de/html/poBitmapMain.html
+# Size: width 11 pixel, height 11 pixel
+
 GetBitmapImage <- function(type) {
-  # Create small bitmap icon images
-  # Bitmap editor: http://www.posoft.de/html/poBitmapMain.html
-  # Size: width 11, height 11
 
   bits <- list()
 
@@ -100,7 +101,7 @@ GetBitmapImage <- function(type) {
   n <- length(bits[[type]]) / 2L
   bits.str <- paste("#define v_width ", n, "\n#define v_height ", n, "\n",
                     "static unsigned char v_bits[] = { ",
-                    paste(bits[[type]], collapse=", "), " }; ", sep="")
+                    paste0(bits[[type]], collapse=", "), " }; ")
 
-  tkimage.create("bitmap", data=as.tclObj(bits.str))
+  return(tkimage.create("bitmap", data=as.tclObj(bits.str)))
 }
